@@ -1,5 +1,4 @@
-{- git-annex command, used internally by old versions of assistant;
- - kept around for now so running daemons don't break when upgraded
+{- git-annex plumbing command (for use by old assistant, and users)
  -
  - Copyright 2012 Joey Hess <joey@kitenet.net>
  -
