@@ -36,7 +36,7 @@ type CommandCleanup = Annex Bool
 {- A command is defined by specifying these things. -}
 data Command = Command
 	{ cmdoptions :: [Option]     -- command-specific options
-	, cmdnorepo :: Maybe (IO ()) -- an action to run when not in a repo
+	, cmdnorepo :: Maybe (CmdParams -> IO ()) -- an action to run when not in a repo
 	, cmdcheck :: [CommandCheck] -- check stage
 	, cmdnocommit :: Bool        -- don't commit journalled state changes
 	, cmdnomessages :: Bool      -- don't output normal messages
@@ -47,6 +47,8 @@ data Command = Command
 	, cmddesc :: String          -- description of command for usage
 	}
 
+type CmdParams = [String]
+
 {- CommandCheck functions can be compared using their unique id. -}
 instance Eq CommandCheck where
 	a == b = idCheck a == idCheck b
